nx.graphic - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic Module

Base class of graphic component

This module provides the following classes:

- nx.geometry.Math
- nx.geometry.Matrix
- nx.graphic.BezierCurves
- nx.graphic.Circle
- nx.graphic.Component
- nx.graphic.Group
- nx.graphic.Icon
- nx.graphic.Icons
- nx.graphic.Image
- nx.graphic.Line
- nx.graphic.Path
- nx.graphic.Polygon
- nx.graphic.Rect
- nx.graphic.Stage
- nx.graphic.Text
- nx.graphic.Triangle